# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import winrt.system
from winrt._winrt_windows_applicationmodel_email_dataprovider import (
    EmailDataProviderConnection,
    EmailDataProviderTriggerDetails,
    EmailMailboxCreateFolderRequest,
    EmailMailboxCreateFolderRequestEventArgs,
    EmailMailboxDeleteFolderRequest,
    EmailMailboxDeleteFolderRequestEventArgs,
    EmailMailboxDownloadAttachmentRequest,
    EmailMailboxDownloadAttachmentRequestEventArgs,
    EmailMailboxDownloadMessageRequest,
    EmailMailboxDownloadMessageRequestEventArgs,
    EmailMailboxEmptyFolderRequest,
    EmailMailboxEmptyFolderRequestEventArgs,
    EmailMailboxForwardMeetingRequest,
    EmailMailboxForwardMeetingRequestEventArgs,
    EmailMailboxGetAutoReplySettingsRequest,
    EmailMailboxGetAutoReplySettingsRequestEventArgs,
    EmailMailboxMoveFolderRequest,
    EmailMailboxMoveFolderRequestEventArgs,
    EmailMailboxProposeNewTimeForMeetingRequest,
    EmailMailboxProposeNewTimeForMeetingRequestEventArgs,
    EmailMailboxResolveRecipientsRequest,
    EmailMailboxResolveRecipientsRequestEventArgs,
    EmailMailboxServerSearchReadBatchRequest,
    EmailMailboxServerSearchReadBatchRequestEventArgs,
    EmailMailboxSetAutoReplySettingsRequest,
    EmailMailboxSetAutoReplySettingsRequestEventArgs,
    EmailMailboxSyncManagerSyncRequest,
    EmailMailboxSyncManagerSyncRequestEventArgs,
    EmailMailboxUpdateMeetingResponseRequest,
    EmailMailboxUpdateMeetingResponseRequestEventArgs,
    EmailMailboxValidateCertificatesRequest,
    EmailMailboxValidateCertificatesRequestEventArgs,
)

__all__ = [
    "EmailDataProviderConnection",
    "EmailDataProviderTriggerDetails",
    "EmailMailboxCreateFolderRequest",
    "EmailMailboxCreateFolderRequestEventArgs",
    "EmailMailboxDeleteFolderRequest",
    "EmailMailboxDeleteFolderRequestEventArgs",
    "EmailMailboxDownloadAttachmentRequest",
    "EmailMailboxDownloadAttachmentRequestEventArgs",
    "EmailMailboxDownloadMessageRequest",
    "EmailMailboxDownloadMessageRequestEventArgs",
    "EmailMailboxEmptyFolderRequest",
    "EmailMailboxEmptyFolderRequestEventArgs",
    "EmailMailboxForwardMeetingRequest",
    "EmailMailboxForwardMeetingRequestEventArgs",
    "EmailMailboxGetAutoReplySettingsRequest",
    "EmailMailboxGetAutoReplySettingsRequestEventArgs",
    "EmailMailboxMoveFolderRequest",
    "EmailMailboxMoveFolderRequestEventArgs",
    "EmailMailboxProposeNewTimeForMeetingRequest",
    "EmailMailboxProposeNewTimeForMeetingRequestEventArgs",
    "EmailMailboxResolveRecipientsRequest",
    "EmailMailboxResolveRecipientsRequestEventArgs",
    "EmailMailboxServerSearchReadBatchRequest",
    "EmailMailboxServerSearchReadBatchRequestEventArgs",
    "EmailMailboxSetAutoReplySettingsRequest",
    "EmailMailboxSetAutoReplySettingsRequestEventArgs",
    "EmailMailboxSyncManagerSyncRequest",
    "EmailMailboxSyncManagerSyncRequestEventArgs",
    "EmailMailboxUpdateMeetingResponseRequest",
    "EmailMailboxUpdateMeetingResponseRequestEventArgs",
    "EmailMailboxValidateCertificatesRequest",
    "EmailMailboxValidateCertificatesRequestEventArgs",
]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.applicationmodel.email as windows_applicationmodel_email
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.security.cryptography.certificates as windows_security_cryptography_certificates

Self = typing.TypeVar('Self')

@typing.final
class EmailDataProviderConnection(winrt.system.Object):
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::Start()
    def start(self) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_CreateFolderRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequestEventArgs>)
    def add_create_folder_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxCreateFolderRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_CreateFolderRequested(Windows.Foundation.EventRegistrationToken)
    def remove_create_folder_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_DeleteFolderRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequestEventArgs>)
    def add_delete_folder_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxDeleteFolderRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_DeleteFolderRequested(Windows.Foundation.EventRegistrationToken)
    def remove_delete_folder_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_DownloadAttachmentRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequestEventArgs>)
    def add_download_attachment_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxDownloadAttachmentRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_DownloadAttachmentRequested(Windows.Foundation.EventRegistrationToken)
    def remove_download_attachment_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_DownloadMessageRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequestEventArgs>)
    def add_download_message_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxDownloadMessageRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_DownloadMessageRequested(Windows.Foundation.EventRegistrationToken)
    def remove_download_message_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_EmptyFolderRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequestEventArgs>)
    def add_empty_folder_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxEmptyFolderRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_EmptyFolderRequested(Windows.Foundation.EventRegistrationToken)
    def remove_empty_folder_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_ForwardMeetingRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequestEventArgs>)
    def add_forward_meeting_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxForwardMeetingRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_ForwardMeetingRequested(Windows.Foundation.EventRegistrationToken)
    def remove_forward_meeting_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_GetAutoReplySettingsRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequestEventArgs>)
    def add_get_auto_reply_settings_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxGetAutoReplySettingsRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_GetAutoReplySettingsRequested(Windows.Foundation.EventRegistrationToken)
    def remove_get_auto_reply_settings_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_MailboxSyncRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequestEventArgs>)
    def add_mailbox_sync_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxSyncManagerSyncRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_MailboxSyncRequested(Windows.Foundation.EventRegistrationToken)
    def remove_mailbox_sync_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_MoveFolderRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequestEventArgs>)
    def add_move_folder_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxMoveFolderRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_MoveFolderRequested(Windows.Foundation.EventRegistrationToken)
    def remove_move_folder_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_ProposeNewTimeForMeetingRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequestEventArgs>)
    def add_propose_new_time_for_meeting_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxProposeNewTimeForMeetingRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_ProposeNewTimeForMeetingRequested(Windows.Foundation.EventRegistrationToken)
    def remove_propose_new_time_for_meeting_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_ResolveRecipientsRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequestEventArgs>)
    def add_resolve_recipients_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxResolveRecipientsRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_ResolveRecipientsRequested(Windows.Foundation.EventRegistrationToken)
    def remove_resolve_recipients_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_ServerSearchReadBatchRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequestEventArgs>)
    def add_server_search_read_batch_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxServerSearchReadBatchRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_ServerSearchReadBatchRequested(Windows.Foundation.EventRegistrationToken)
    def remove_server_search_read_batch_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_SetAutoReplySettingsRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequestEventArgs>)
    def add_set_auto_reply_settings_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxSetAutoReplySettingsRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_SetAutoReplySettingsRequested(Windows.Foundation.EventRegistrationToken)
    def remove_set_auto_reply_settings_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_UpdateMeetingResponseRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequestEventArgs>)
    def add_update_meeting_response_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxUpdateMeetingResponseRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_UpdateMeetingResponseRequested(Windows.Foundation.EventRegistrationToken)
    def remove_update_meeting_response_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.Foundation.EventRegistrationToken Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::add_ValidateCertificatesRequested(Windows.Foundation.TypedEventHandler`2<Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection,Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequestEventArgs>)
    def add_validate_certificates_requested(self, handler: windows_foundation.TypedEventHandler[EmailDataProviderConnection, EmailMailboxValidateCertificatesRequestEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection::remove_ValidateCertificatesRequested(Windows.Foundation.EventRegistrationToken)
    def remove_validate_certificates_requested(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...

@typing.final
class EmailDataProviderTriggerDetails(winrt.system.Object):
    # Windows.ApplicationModel.Email.DataProvider.EmailDataProviderConnection Windows.ApplicationModel.Email.DataProvider.EmailDataProviderTriggerDetails::get_Connection()
    @_property
    def connection(self) -> EmailDataProviderConnection: ...

@typing.final
class EmailMailboxCreateFolderRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest::ReportCompletedAsync(Windows.ApplicationModel.Email.EmailFolder)
    def report_completed_async(self, folder: windows_applicationmodel_email.EmailFolder, /) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest::ReportFailedAsync(Windows.ApplicationModel.Email.EmailMailboxCreateFolderStatus)
    def report_failed_async(self, status: windows_applicationmodel_email.EmailMailboxCreateFolderStatus, /) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest::get_Name()
    @_property
    def name(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest::get_ParentFolderId()
    @_property
    def parent_folder_id(self) -> str: ...

@typing.final
class EmailMailboxCreateFolderRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxCreateFolderRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxCreateFolderRequest: ...

@typing.final
class EmailMailboxDeleteFolderRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequest::ReportFailedAsync(Windows.ApplicationModel.Email.EmailMailboxDeleteFolderStatus)
    def report_failed_async(self, status: windows_applicationmodel_email.EmailMailboxDeleteFolderStatus, /) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequest::get_EmailFolderId()
    @_property
    def email_folder_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...

@typing.final
class EmailMailboxDeleteFolderRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxDeleteFolderRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxDeleteFolderRequest: ...

@typing.final
class EmailMailboxDownloadAttachmentRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest::get_EmailAttachmentId()
    @_property
    def email_attachment_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest::get_EmailMessageId()
    @_property
    def email_message_id(self) -> str: ...

@typing.final
class EmailMailboxDownloadAttachmentRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadAttachmentRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxDownloadAttachmentRequest: ...

@typing.final
class EmailMailboxDownloadMessageRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequest::get_EmailMessageId()
    @_property
    def email_message_id(self) -> str: ...

@typing.final
class EmailMailboxDownloadMessageRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxDownloadMessageRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxDownloadMessageRequest: ...

@typing.final
class EmailMailboxEmptyFolderRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequest::ReportFailedAsync(Windows.ApplicationModel.Email.EmailMailboxEmptyFolderStatus)
    def report_failed_async(self, status: windows_applicationmodel_email.EmailMailboxEmptyFolderStatus, /) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequest::get_EmailFolderId()
    @_property
    def email_folder_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...

@typing.final
class EmailMailboxEmptyFolderRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxEmptyFolderRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxEmptyFolderRequest: ...

@typing.final
class EmailMailboxForwardMeetingRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_Comment()
    @_property
    def comment(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_EmailMessageId()
    @_property
    def email_message_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_ForwardHeader()
    @_property
    def forward_header(self) -> str: ...
    # Windows.ApplicationModel.Email.EmailMessageBodyKind Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_ForwardHeaderType()
    @_property
    def forward_header_type(self) -> windows_applicationmodel_email.EmailMessageBodyKind: ...
    # Windows.Foundation.Collections.IVectorView`1<Windows.ApplicationModel.Email.EmailRecipient> Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_Recipients()
    @_property
    def recipients(self) -> typing.Sequence[windows_applicationmodel_email.EmailRecipient]: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest::get_Subject()
    @_property
    def subject(self) -> str: ...

@typing.final
class EmailMailboxForwardMeetingRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxForwardMeetingRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxForwardMeetingRequest: ...

@typing.final
class EmailMailboxGetAutoReplySettingsRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequest::ReportCompletedAsync(Windows.ApplicationModel.Email.EmailMailboxAutoReplySettings)
    def report_completed_async(self, auto_reply_settings: windows_applicationmodel_email.EmailMailboxAutoReplySettings, /) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # Windows.ApplicationModel.Email.EmailMailboxAutoReplyMessageResponseKind Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequest::get_RequestedFormat()
    @_property
    def requested_format(self) -> windows_applicationmodel_email.EmailMailboxAutoReplyMessageResponseKind: ...

@typing.final
class EmailMailboxGetAutoReplySettingsRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxGetAutoReplySettingsRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxGetAutoReplySettingsRequest: ...

@typing.final
class EmailMailboxMoveFolderRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::get_EmailFolderId()
    @_property
    def email_folder_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::get_NewFolderName()
    @_property
    def new_folder_name(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest::get_NewParentFolderId()
    @_property
    def new_parent_folder_id(self) -> str: ...

@typing.final
class EmailMailboxMoveFolderRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxMoveFolderRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxMoveFolderRequest: ...

@typing.final
class EmailMailboxProposeNewTimeForMeetingRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_Comment()
    @_property
    def comment(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_EmailMessageId()
    @_property
    def email_message_id(self) -> str: ...
    # Windows.Foundation.TimeSpan Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_NewDuration()
    @_property
    def new_duration(self) -> datetime.timedelta: ...
    # Windows.Foundation.DateTime Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_NewStartTime()
    @_property
    def new_start_time(self) -> datetime.datetime: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest::get_Subject()
    @_property
    def subject(self) -> str: ...

@typing.final
class EmailMailboxProposeNewTimeForMeetingRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxProposeNewTimeForMeetingRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxProposeNewTimeForMeetingRequest: ...

@typing.final
class EmailMailboxResolveRecipientsRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequest::ReportCompletedAsync(Windows.Foundation.Collections.IIterable`1<Windows.ApplicationModel.Email.EmailRecipientResolutionResult>)
    def report_completed_async(self, resolution_results: typing.Iterable[windows_applicationmodel_email.EmailRecipientResolutionResult], /) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # Windows.Foundation.Collections.IVectorView`1<System.String> Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequest::get_Recipients()
    @_property
    def recipients(self) -> typing.Sequence[str]: ...

@typing.final
class EmailMailboxResolveRecipientsRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxResolveRecipientsRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxResolveRecipientsRequest: ...

@typing.final
class EmailMailboxServerSearchReadBatchRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::ReportFailedAsync(Windows.ApplicationModel.Email.EmailBatchStatus)
    def report_failed_async(self, batch_status: windows_applicationmodel_email.EmailBatchStatus, /) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::SaveMessageAsync(Windows.ApplicationModel.Email.EmailMessage)
    def save_message_async(self, message: windows_applicationmodel_email.EmailMessage, /) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::get_EmailFolderId()
    @_property
    def email_folder_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # Windows.ApplicationModel.Email.EmailQueryOptions Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::get_Options()
    @_property
    def options(self) -> windows_applicationmodel_email.EmailQueryOptions: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::get_SessionId()
    @_property
    def session_id(self) -> str: ...
    # System.UInt32 Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest::get_SuggestedBatchSize()
    @_property
    def suggested_batch_size(self) -> winrt.system.UInt32: ...

@typing.final
class EmailMailboxServerSearchReadBatchRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxServerSearchReadBatchRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxServerSearchReadBatchRequest: ...

@typing.final
class EmailMailboxSetAutoReplySettingsRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.ApplicationModel.Email.EmailMailboxAutoReplySettings Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequest::get_AutoReplySettings()
    @_property
    def auto_reply_settings(self) -> windows_applicationmodel_email.EmailMailboxAutoReplySettings: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...

@typing.final
class EmailMailboxSetAutoReplySettingsRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxSetAutoReplySettingsRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxSetAutoReplySettingsRequest: ...

@typing.final
class EmailMailboxSyncManagerSyncRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...

@typing.final
class EmailMailboxSyncManagerSyncRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxSyncManagerSyncRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxSyncManagerSyncRequest: ...

@typing.final
class EmailMailboxUpdateMeetingResponseRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::ReportCompletedAsync()
    def report_completed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_Comment()
    @_property
    def comment(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_EmailMessageId()
    @_property
    def email_message_id(self) -> str: ...
    # Windows.ApplicationModel.Email.EmailMeetingResponseType Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_Response()
    @_property
    def response(self) -> windows_applicationmodel_email.EmailMeetingResponseType: ...
    # System.Boolean Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_SendUpdate()
    @_property
    def send_update(self) -> bool: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest::get_Subject()
    @_property
    def subject(self) -> str: ...

@typing.final
class EmailMailboxUpdateMeetingResponseRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxUpdateMeetingResponseRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxUpdateMeetingResponseRequest: ...

@typing.final
class EmailMailboxValidateCertificatesRequest(winrt.system.Object):
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequest::ReportCompletedAsync(Windows.Foundation.Collections.IIterable`1<Windows.ApplicationModel.Email.EmailCertificateValidationStatus>)
    def report_completed_async(self, validation_statuses: typing.Iterable[windows_applicationmodel_email.EmailCertificateValidationStatus], /) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.IAsyncAction Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequest::ReportFailedAsync()
    def report_failed_async(self) -> windows_foundation.IAsyncAction: ...
    # Windows.Foundation.Collections.IVectorView`1<Windows.Security.Cryptography.Certificates.Certificate> Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequest::get_Certificates()
    @_property
    def certificates(self) -> typing.Sequence[windows_security_cryptography_certificates.Certificate]: ...
    # System.String Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequest::get_EmailMailboxId()
    @_property
    def email_mailbox_id(self) -> str: ...

@typing.final
class EmailMailboxValidateCertificatesRequestEventArgs(winrt.system.Object):
    # Windows.Foundation.Deferral Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequestEventArgs::GetDeferral()
    def get_deferral(self) -> windows_foundation.Deferral: ...
    # Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequest Windows.ApplicationModel.Email.DataProvider.EmailMailboxValidateCertificatesRequestEventArgs::get_Request()
    @_property
    def request(self) -> EmailMailboxValidateCertificatesRequest: ...

